#from cfunits import Units <- Not needed, but can be useful in a future
#import f90nml <- Not needed, but can be useful in a future
import numpy as np
import metview as mv
import os

#input_file = "SS_ug_m-3.grb"    # um_m-3 means micro grams per cubic meter.
input_file = "DU_ug_m-3.grb"    # um_m-3 means micro grams per cubic meter.

contour_lines = [0.0, 10.0, 20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0, 90.0, 100.0, 150.0, 200.0, 250.0, 300.0, 350.0, 400.0, 450.0, 500.0, 600.0, 700.0, 800.0, 900.0, 1000.0]

# Texts for the graphic
# The main title is set by a command line option, so it is not set here
x_axis_title = "Fecha de la predicción"
y_axis_title = "Presión (hPa)"


field_to_plot_per_volume = mv.read(input_file)

# Draw the graphic
print("Drawing ...")

Legend = mv.mlegend(legend_text_font_size = 0.3, legend_label_frequency= 1)

lon = -16.5
lat = 28.5
grid_spacing = 0.5

out_file = os.path.splitext(input_file)[0]
png = mv.png_output(output_name = out_file, output_name_first_page_number = "off",
    output_width = 1200, output_font_scale = 2)
mv.setoutput(png)

# An area that inclues only one point will be used only for the hovmoeller plot
area_hov   = (lat+grid_spacing/3, lon-grid_spacing/3, lat-grid_spacing/3, lon+grid_spacing/3)

# Find the maximum value that will be plotted
nearest_values = np.array(mv.nearest_gridpoint(field_to_plot_per_volume, [lat, lon]))
nearest_values[nearest_values == None] = np.nan
nearest_values = np.array(nearest_values,dtype=float)
max_value = np.nanmax(nearest_values)

Contouring = mv.mcont(
    legend                         = "on",
    contour_reference_level        = contour_lines[0],
    contour_level_selection_type   = "level_list",
    contour_level_list             = contour_lines,
#    contour_max_level              = max_value, # If I uncomment this, only the plotted range will apperar in the legend, but
                                                 # if all values are between zero and the next contour value, the graphic is blank.
    contour_min_level              = 0,
    contour_line_colour            = 'BLACK',
    contour_line_thickness         = 1,
    contour_highlight              = 'off',
    contour_label_blanking         = "off",
    contour_label_height           = 0.2,
    contour_label_frequency        = 4,
    contour_shade                  = "on",
    contour_shade_technique        = "polygon_shading", # cell_shading for a faster plot, grid_shading will 
                                                     # give the most accurate results, but this can be slower for larger areas.
    #contour_shade_cell_resolution  = 50,
    contour_shade_method           = "area_fill",
    contour_shade_cell_method      = "nearest",
    contour_internal_reduction_factor = 1.0,
    contour_shade_min_level_colour = "blue",
    contour_shade_max_level_colour = "red",
    contour_interpolation_floor    = 0, # Important to not to get a weird horizontal line below
    contour_interpolation_ceiling  = 1E21,
    contour_hilo = "on",
    contour_hilo_marker = "on",
    contour_hilo_marker_index = 3,
    contour_hilo_marker_height = 0.6,
    contour_hilo_marker_colour = "white",
    contour_hilo_type = "number", #"both",
    contour_hilo_height = 0.2,
    contour_hi_colour = "white",
    contour_hilo_format = "(F0.0)",
    contour_hilo_min_value = contour_lines[1]
    )

title_lines=["Razón de mezcla (&mu;g/m<sup>3</sup>) de aerosoles de sal marina (0.03 - 20 &mu;m)", ""]
            
Text_Plotting = mv.mtext(
    text_line_count = len(title_lines), # The second line is blank, just to increase vertical space
    text_lines = title_lines,
    text_font_size = 0.6
    )


def build_layout(area_hov):
   #PageDescription
      
    Vertical_Axis = mv.maxis(
        AXIS_ORIENTATION   = "VERTICAL",
        AXIS_TITLE_TEXT    = y_axis_title,
        axis_title_position = 200,
        AXIS_TYPE          = "POSITION_LIST",
        AXIS_TICK_POSITION_LIST = [1000, 900, 800, 700, 600, 500, 400,300],
        #AXIS_TICK_INTERVAL = 10, # Ignored when AXIS_TYPE = "LOGARITHMIC"
        #axis_tick_label_frequency = 1,
        axis_tick_label_height = 0.4
        )
      
    Horizontal_Axis = mv.maxis(
        AXIS_ORIENTATION   = "HORIZONTAL",
        AXIS_TITLE_TEXT    = x_axis_title,
        axis_days_label = 'number',
        axis_days_label_height = 0.4,
        axis_years_label_height = 0.4,
        axis_months_label_height = 0.4
#        axis_days_sunday_label_colour = 'BLACK' 
        )
   
    HovmoellerView2 = mv.mhovmoellerview(
        TYPE                      = "VERTICAL_HOVM",
        AREA                      = area_hov,
        TIME_AXIS_MODE            = "AUTOMATIC_FORWARDS",
        BOTTOM_LEVEL              = 1000,
        TOP_LEVEL                 = 300,
        VERTICAL_LEVEL_TYPE       = "as_in_data",
        VERTICAL_SCALING          = "LOG",
        SUBPAGE_CLIPPING          = "OFF",
        SUBPAGE_X_POSITION        = 12,
        SUBPAGE_Y_POSITION        = 10, # Messured in percentage from the bottom
        SUBPAGE_X_LENGTH          = 75,
        SUBPAGE_Y_LENGTH          = 80, # If this is smaller, the title also goes down.
        PAGE_FRAME                = "OFF",
        PAGE_ID_LINE              = "OFF",
        SUBPAGE_FRAME             = "ON",
        SUBPAGE_FRAME_COLOUR      = "BLACK",
        SUBPAGE_FRAME_LINE_STYLE  = "SOLID",
        SUBPAGE_FRAME_THICKNESS   = 2,
        SUBPAGE_BACKGROUND_COLOUR = "NONE",
        VERTICAL_AXIS             = Vertical_Axis,
        TIME_AXIS                 = Horizontal_Axis
        )
    
   
    _Page_ = mv.plot_page(
        TOP       = 7.5,
        BOTTOM    = 100,
        LEFT      = 0,
        RIGHT     = 100,
        VIEW      = HovmoellerView2
    )
   
    # SuperPage descriptiondone

    _Display_Window_ = mv.plot_superpage(
        LAYOUT_SIZE        = "A4",
        LAYOUT_ORIENTATION = "LANDSCAPE",
        CUSTOM_WIDTH       = 29.7,
        CUSTOM_HEIGHT      = 21.0,
        PAGES              = [ _Page_ ]
    )
   # plot_superpage returns a list of drop identifiers.
   # Index 1 is for first page, and so on.

    return _Display_Window_
# end build_layout

# Call function to build layout (defined at end of macro)
dw = build_layout(area_hov)
# Plot command
mv.plot ( dw[0], field_to_plot_per_volume, Legend, Contouring, Text_Plotting )




